package com.xinelu.manage.service.nursestationperson;

import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.manage.domain.nursestationperson.NurseStationPerson;
import com.xinelu.manage.dto.nursestationperson.NurseStationPersonCheckDTO;
import com.xinelu.manage.dto.nursestationperson.NurseStationPersonDTO;
import com.xinelu.manage.dto.nursestationperson.NurseStationPersonImportDTO;
import com.xinelu.manage.vo.nursestationperson.NurseStationPersonVO;

import java.util.List;

/**
 * 护理站人员信息Service接口
 *
 * @author ljh
 * @date 2022-09-02
 */
public interface INurseStationPersonService {
    /**
     * 查询护理站人员信息
     *
     * @param id 护理站人员信息主键
     * @return 护理站人员信息
     */
    NurseStationPersonVO selectNurseStationPersonById(Long id);

    /**
     * 查询护理站人员信息列表
     *
     * @param nurseStationPerson 护理站人员信息
     * @return 护理站人员信息集合
     */
    List<NurseStationPerson> selectNurseStationPersonList(NurseStationPerson nurseStationPerson);

    /**
     * 新增护理站人员信息
     *
     * @param nurseStationPerson 护理站人员信息
     * @return 结果
     */
    AjaxResult insertNurseStationPersonList(NurseStationPersonDTO nurseStationPerson);

    /**
     * 修改护理站人员信息
     *
     * @param nurseStationPerson 护理站人员信息
     * @return 结果
     */
    AjaxResult updateNurseStationPerson(NurseStationPersonDTO nurseStationPerson);

    /**
     * 批量删除护理站人员信息
     *
     * @param ids 需要删除的护理站人员信息主键集合
     * @return 结果
     */
    AjaxResult deleteNurseStationPersonByIds(Long[] ids);

    /**
     * 删除护理站人员信息信息
     *
     * @param id 护理站人员信息主键
     * @return 结果
     */
    int deleteNurseStationPersonById(Long id);

    /**
     * 查询护理站人员信息以及护理站名称集合
     *
     * @param nurseStationPerson 护理站人员信息集合
     * @return java.util.List<com.xinyilu.base.vo.nursestationperson.NurseStationPersonVO>
     **/
    List<NurseStationPersonVO> getNurseStationPersonList(NurseStationPersonVO nurseStationPerson);


    /**
     * 护理站人员导入
     *
     * @param nurseStationPerson 护理站人员信息
     * @return int
     **/
    AjaxResult insertNurseStationPersonImportList(List<NurseStationPersonImportDTO> nurseStationPerson);


    /**
     * 审核接口根据id查询护理站人员信息以及未审核的证书
     *
     * @param id 护理站人员信息主键
     * @return 护理站人员信息
     */
    NurseStationPersonCheckDTO getNurseStationPersonCheck(Long id);

    /**
     * 管理端更新护理人员主表信息与证书信息
     *
     * @param nurseStationPersonCheckDTO 护理人员主表信息与证书信息
     * @return AjaxResult
     * @throws Exception 异常信息
     */
    AjaxResult updateNurseStationPersonChecks(NurseStationPersonCheckDTO nurseStationPersonCheckDTO) throws Exception;
}